@@ -36,8 +36,6 @@
 #ifndef CV_H_
 #define CV_H_
 
-#include "../lars/Lars.h"
-#include "../lars/functions.h"
 #include "IAlgo.h"
 
 namespace HD
